<template>
  <FormSection
    description="app.profile.delete.description"
    title="app.profile.delete.title"
  >
    <div class="text-sm text-gray-600">
      {{ $t("app.profile.delete.info") }}
    </div>
    <div>
      <button
        class="btn btn-red"
        type="button"
        @click="modal.open()"
      >
        {{ $t("app.profile.delete.submit") }}
      </button>
    </div>
  </FormSection>
  <ModalDialog ref="confirmModal">
    <ModalHeader>
      <ModalTitle>
        {{ $t("app.profile.delete.title") }}
      </ModalTitle>
    </ModalHeader>
    <ModalForm @submit="submit">
      <template #default>
        <AlertError v-if="form.errors && form.errors?.unknown">
          {{ form.errors.unknown }}
        </AlertError>
        <div class="text-sm text-gray-500">
          {{ $t("app.profile.delete.confirm") }}
        </div>
        <FormInput
          id="delete_password"
          :errors="form.errors.password"
        >
          <FormLabel>{{ $t("app.profile.form.password_confirmation") }}</FormLabel>
          <FormText
            v-model="form.values.password"
            autocomplete="password"
            name="password"
            required
            type="password"
          />
        </FormInput>
      </template>
      <template #footer>
        <FormSubmit
          :processing="form.isFetching"
          class="btn btn-red"
        >
          {{ $t("app.profile.delete.submit") }}
        </FormSubmit>
      </template>
    </ModalForm>
  </ModalDialog>
</template>

<script lang="ts" setup>
import FormSection from "@/js/contexts/form/ui/components/FormSection.vue";
import ModalDialog from "@/js/contexts/shared/ui/components/modal/ModalDialog.vue";
import ModalForm from "@/js/contexts/shared/ui/components/modal/ModalForm.vue";
import FormSubmit from "@/js/contexts/form/ui/components/FormSubmit.vue";
import FormInput from "@/js/contexts/form/ui/components/FormInput.vue";
import ModalTitle from "@/js/contexts/shared/ui/components/modal/ModalTitle.vue";
import FormLabel from "@/js/contexts/form/ui/components/FormLabel.vue";
import ModalHeader from "@/js/contexts/shared/ui/components/modal/ModalHeader.vue";
import FormText from "@/js/contexts/form/ui/components/FormText.vue";
import useModal from "@/js/contexts/shared/composables/useModal";
import useForm from "@/js/contexts/shared/composables/useForm";
import useAuth from "@/js/contexts/auth/composables/useAuth";
import AlertError from "@/js/contexts/shared/ui/components/alert/AlertError.vue";
import useSnowflake from "@/js/contexts/shared/composables/useSnowflake";

const router = useRouter();
const { logout } = useAuth();
const { props } = useSnowflake();
const confirmModal = ref<InstanceType<typeof ModalDialog>>();
const modal = useModal(confirmModal);

const form = useForm({
  password: "",
});

const submit = () => {
  form.delete("/profile/delete", {
    onSuccess: () => {
      logout().then(() => router.push({ name: props.links.homepage ? "index" : "login" }));
    },
  });
};
</script>
